import React, { PropTypes } from 'react'

const parseProps = ({
  truncate,
  style,
  ...props
}) => {
  const styles = {}

  if (truncate) {
    styles.whiteSpace = 'nowrap'
    styles.overflow = 'hidden'
    styles.textOverflow = 'ellipsis'
  }

  return { style: { ...styles, ...style }, ...props }
}

const withTruncate = (Comp) => {
  const TruncateComp = (originalProps) => {
    return React.createElement(Comp, parseProps(originalProps))
  }

  TruncateComp.propTypes = {
    ...Comp.propTypes,
    truncate: PropTypes.bool
  }

  TruncateComp.displayName = Comp.displayName

  return TruncateComp
}

export {
  withTruncate
}
